@@ -200,16 +200,13 @@ fn draw(text_0: Vec<Spans>, text_1: Vec<Spans>, terminal: &mut Terminal<Crosster
 
 #[tokio::main]
 async fn main() {
+    println!("Authenticating...");
+    let token = authenticate().await;
+
     let mut term_backend = CrosstermBackend::new(stdout());
     term_backend.clear().unwrap();
     let mut terminal = Terminal::new(term_backend).unwrap();
 
-    draw(
-        vec![Spans::from("Authenticating...")],
-        vec![],
-        &mut terminal,
-    );
-    let token = authenticate().await;
     draw(
         vec![Spans::from("Getting mentions...")],
         vec![],
